function [w, theta_x, theta_y] = CL_U_Circle(X, Y, a, Props, q)

%  function [w, theta_x, theta_y] = CL_U_Circle(X, Y, a, Props, q)
%
%  To evaluate the deflection and rotations of a 
%  CL-U circular plate of the radius 'a' at points (X,Y)
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 30 June 2006
%
%  Input
%  X and Y:  Matrices of x and y where the deflection and rotations 
%            are evaluated
%  a:  radius of the plate
%  Props:  Elastic modulus, Poisson's ratio, plate thickness
%  q:  Uniform load
%
%  Output
%  w:  Matrix of deflection at points (X,Y)
%  theta_x, theta_y:  Matrices of rotations about x and y axes,
%                     respectively, at points (X,Y)
%
%  Reference:  Reismann (1988)
%

E=Props(1,1);  nu=Props(1,2);  h=Props(1,3);
G=E/2/(1+nu); k=5/6;
%  Flexural rigidity
D=E*h^3/12/(1-nu^2);

%
%  Polar Coordinates
[theta, r]= cart2pol(X,Y);
c=cos(theta);  s=sin(theta);
%
%  Deflection
%  Reissmann p.142 Eq. 5.133b
w= q/64/D*(a^2-r.^2).^2 + q/(4*k*G*h)*(a^2-r.^2);

%  Rotation in the r direction
psi= q*a^2/16/D*r.*(1- r.^2/a^2);
%  Rotation about -y axis
psi_x = psi.*c;
%  Rotation about x axis
psi_y = psi.*s;
%
theta_x= -psi_y;
theta_y= psi_x;