%
%  List of m-files and functions for Displacement-based 
%  Kriging FE program for plate bending problems
%
%  Developed by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 17 March 2006
%  Last modification:  27 September 2006
%

%  SSH_U_dat.m:  An example for developing and verifying K-FE program
%  Go.m:  The main program of linear elastic K-FEA of the structure
%  Go_Post.m:  Post-processing program for linear elastic K-FEA
%              of the structure
%  SSU0_dat:  a quarter of a SS-U square plate with 15x15 regularly-distributed nodes
%  SSC0_dat:  a quarter of a SS-C square plate with 15x15 regularly-distributed nodes
%  CLU0_dat:  a quarter of a CL-U square plate with 15x15 regularly-distributed nodes
%  CLC0_dat:  a quarter of a CL-C square plate with 15x15 regularly-distributed nodes
%  CircleCLU_dat:  a quarter of a CL-U circular plate
%

%  Pre-processing functions:
%  Rect_nodes:  to generate the equally-spaced nodal coordinates
%               and their numerical label for a rectangular domain
%  Rhom_nodes:  to generate the equally-spaced nodal coordinates
%               and their numerical label for an equal-side 
%               rhombic domain (parallelogram) with x axis parallel
%               to one side of the parallelogram and the x axis and 
%               that side comprise a sharp angle
%  Tri_mesh_A:  to generate the element connectivity matrix 
%               for mesh comprising of triangular elements
%               whose hypotenuse run from upper-left to lower-down (Mesh A)
%               The nodes are the output of Rect_nodes.m or Rhom_nodes.m
%

%  General K-FEA functions:
%  Global_dof:  to obtain global (structural) parameter indices for an element
%  El_stiff2str:  to transform element stiffness matrix
%                 to structural size
%  El_load2str:  to transform element load vector to structural size
%  Node2eqns:  to convert a data matrix written in 'per node' format 
%              to a vector of data, which is listed according to equation
%              indices
%  Eqns2node:  to convert a vector of data, which is listed according to 
%              equation indeces, to a data matrix written in 'per node'
%              format
%  Modify:  to modify a structural stiffness matrix and a structural load vector
%           in order to conform to given prescribed displacements
%  Solution:  to obtain all of nodal displacements
%  Reaction:  to obtain reaction forces at nodes with fixed dofs or
%             at nodes with prescribed displacements
%

%  Finite element plotting functions:
%  Plot_Undeform_TRI:  to plot undeformed shape of the structure without
%                      element labels
%  Plot_Undeform:  to plot undeformed shape of a structural finite element model
%  Plot_Deform3D:  to plot deformed shape of a plate bending in 3D space
%  Plot_Deform:  to plot deflection and rotation contours
%  Plot_Moments:  to plot moment contours
%  Plot_Ave_Moments:  to plot moment contours in another figure
%  Plot_Shears:  to plot shear force contours
%  Plot_Ave_Shears:  to plot shear force contours in another figure
%    

%  General functions:
%  Isin:  true if the scalar c is contained in the vector X
%  Del_same:  to delete the same elements in a vector
%  Nonzero_index: to unify nonzero indices of two column vectors
%  Tri_integral:  to return the positions of integration points and 
%                 their weights for a triangular element
%                 using Nsamp-point formula
%  Max_Distance:  to return the maximum distance between nodes
%  

%  Kriging interpolation related functions:
%  R_Gauss:  to evaluate the value of gaussian 
%            correlation function and its derivatives
%  R_quartic:  to evaluate the values of the quartic spline
%              correlation function and its derivatives
%  R_cubic:  to evaluates the values of the cubic spline
%            correlation function and its derivatives (not complete!)
%  Kriging_shapef:  to return the values of kriging shape functions 
%                   and their first derivatives with respect to
%                   x and y.  It is only for functions with 2D domain.
%  Kriging_shapef2:  to return the values of kriging shape functions 
%                    and their first and second derivatives with respect to
%                    x and y.  It is only for functions with 2D domain.
%  Nodes_DOI:  to generate the node numbers in an N_layer
%              influence domain
%

%  Two dimensional kriging triangular element functions:
%  Echo_data:  to give general information of the input data file and to feed
%              the necessary input for subsequent calculation processes
%  Delaunay_order:  to returns triangular connectivity in the anticlockwise
%                   direction and the total number of triangles
%  Modps:  to evaluate the constitutive matrices
%  Shape_fun:  to stablish shape function matrix and bending strain-displacement
%              matrices at sampling point for a plate element
%  Deriv_s:  to establish shearing strain-displacement
%            matrix at sampling point for a plate element 
%  Stif_bodyps_Kplate:  to generate the stiffness matrix and equivalent 
%                       nodal body force vector for a kriging plate bending
%                       element.  It uses the same interpolation functions 
%                       for displacement and rotations
%

%  Post-processing functions:
%  Moment_fun:  to calculate bending and twisting moments for a kriging plate bending element               
%  Shear_fun:  to calculate shear forces for a kriging plate bending element
%              by using shear strains
%  Shear2_fun:  to calculate shear forces using kriging from nodal moments
%  Moment_Shear_fun:  to calculate bending and twisting moments 
%                     and shear forces using the shear strains
%                     for a kriging plate bending element
%  Moment_Shear_fun3:  to calculate bending and twisting moments 
%                      and shear forces using kriging from nodal rotations
%  Moment_ave:  to calculate the average values of moments at common nodes
%  Shear_ave:  to calculate the average values of shears at common nodes
%  Moment_Shear_ave:  to calculate the average values of moments and shears 
%                     at common nodes
%  
