function [PHI, DxPHI, DyPHI, D2xPHI, DxDyPHI, D2yPHI] = ...
         Kriging_shapef2 (Coord_DOI, theta, d, P_order, xy, Cor_type)

%  [PHI, DxPHI, DyPHI, D2xPHI, DxDyPHI, D2yPHI] = ...
%  Kriging_shapef2 (Coord_DOI, theta, d, P_order, xy, Cor_type)
%
%  Kriging_shapef2 returns the values of kriging shape functions 
%  and their first and second derivatives with respect to
%  x and y.  It is only for functions with 2D domain.
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 5 September 2005
%  Last modification: 15 March 2006
%
%  Input
%  Coord_DOI:  matrix of nodal coordinates in the influence domain
%              n*2
%  theta:  parameter of gaussian correlation function
%  d:  a scale (distance) to normalize the distance between 
%      the nodes and the point(s) at which function value(s) are
%      sought
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation 
%            (1. Linear, 2. Quadratic, 3. Cubic, 4. Quartic
%            5. Bi-linear, 6. Bi-quadratic  7. Bi-cubic)
%  xy:  matrix of coordinate(s) of point(s) at which function value(s)
%       are sought, n_xy*2
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%                                           3-Cubic spline
%  Output
%  PHI:  matrix of the values of kriging shape functions, n_xy*n
%  DxPHI, DyPHI:  matrices of the values of kriging function first 
%                 derivatives with respect to x and y, respectively, n_xy*n
%  D2xPHI, DxDyPHI, D2yPHI:  
%                 matrices of the values of kriging function second
%                 derivatives with respect to x, y and, x and y, respectively,
%                  n_xy*n
%  Reference
%  Tjong, W.F. (2005).  'Ch3. Kriging Interpolation', 
%  AIT Dissertation Draft
%
n=size(Coord_DOI,1);
switch Cor_type
    case 1
    Cor1=[ 'R(i_DOI, j_DOI) = ' ...
    'R_Gauss(Coord_DOI(i_DOI,:), Coord_DOI(j_DOI,:), theta, d);' ];
    Cor2=[ '[r(i_DOI,1), Dr, D2r] = ' ...
           'R_Gauss (xy(i_x,:), Coord_DOI(i_DOI,:), theta, d);' ];
    case 2
    Cor1=[ 'R(i_DOI, j_DOI) = ' ...
    'R_quartic(Coord_DOI(i_DOI,:), Coord_DOI(j_DOI,:), theta, d);' ];
    Cor2=[ '[r(i_DOI,1), Dr, D2r] = ' ...
            'R_quartic (xy(i_x,:), Coord_DOI(i_DOI,:), theta, d);' ];
    case 3
    Cor1=[ 'R(i_DOI, j_DOI) = ' ...
    'R_cubic( Coord_DOI(i_DOI,:), Coord_DOI(j_DOI,:), theta, d);' ];
    Cor2=[ '[r(i_DOI,1), Dr] = ' ...
            'R_cubic( xy(i_x,:), Coord_DOI(i_DOI,:), theta, d);' ];
    otherwise
    error('Wrong type of correlation function!!');
end

%
switch P_order
    case 1
    m=3;
    P=zeros(n,m);  R=zeros(n,n);
    for i_DOI=1:n
       P(i_DOI,:)=[ 1 Coord_DOI(i_DOI,:)];
       for j_DOI=1:n
          eval(Cor1);
       end
    end
    det_R=det(R);
    if det_R>0.01
       disp( ['det(R)=', num2str(det_R),' is NOT okay'] )
       error('Theta is too large!!');
    end
    G=[ R   P
        P'  zeros(m,m)];
    clear R P i_DOI j_DOI
    %
    n_xy=size(xy,1);
    r=zeros(n,1);
    Dxr=zeros(n,1);  Dyr=zeros(n,1);
    D2xr=zeros(n,1);  DxDyr=zeros(n,1);
    D2yr=zeros(n,1);
    %
    g=zeros(n+m,n_xy);
    Dxg=zeros(n+m,n_xy);  Dyg=zeros(n+m,n_xy);
    D2xg=zeros(n+m,n_xy);  DxDyg=zeros(n+m,n_xy);
    D2yg=zeros(n+m,n_xy);
    %
    Dp=[0  0
        1  0
        0  1];
    D2p=[0  0  0
         0  0  0
         0  0  0];
    for i_x=1:n_xy
       p = [1; xy(i_x,:)'];  %  Basis function
       for i_DOI=1:n
          eval(Cor2);
          Dxr(i_DOI,1)=Dr(1,1);  Dyr(i_DOI,1)=Dr(2,1);
          D2xr(i_DOI,1)=D2r(1,1);  DxDyr(i_DOI,1)=D2r(2,1);
          D2yr(i_DOI,1)=D2r(3,1);
       end
       %
       g(:,i_x)  = [ r ; p ];
       Dxg(:,i_x) = [ Dxr ; Dp(:,1) ];
       Dyg(:,i_x) = [ Dyr ; Dp(:,2) ];
       D2xg(:,i_x) = [ D2xr ; D2p(:,1) ];
       DxDyg(:,i_x) = [ DxDyr ; D2p(:,2) ];
       D2yg(:,i_x) = [ D2yr ; D2p(:,3) ];
    end
    %
    %
    case 2
    m=6;
    P=zeros(n,m);  R=zeros(n,n);
    for i_DOI=1:n
       P(i_DOI,:)=[ 1 Coord_DOI(i_DOI,:) Coord_DOI(i_DOI,1).^2 ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2) Coord_DOI(i_DOI,2).^2 ];
       for j_DOI=1:n
          eval(Cor1);
       end
    end
    det_R=det(R);
    if det_R>0.01
       disp( ['det(R)=', num2str(det_R),' is NOT okay'] )
       error('Theta is too large!!');
    end
    G=[ R   P
        P'  zeros(m,m)];
    clear R P i_DOI j_DOI
    %
    n_xy=size(xy,1);
    r=zeros(n,1);
    Dxr=zeros(n,1);  Dyr=zeros(n,1);
    D2xr=zeros(n,1);  DxDyr=zeros(n,1);
    D2yr=zeros(n,1);
    %
    g=zeros(n+m,n_xy);
    Dxg=zeros(n+m,n_xy);  Dyg=zeros(n+m,n_xy);
    D2xg=zeros(n+m,n_xy);  DxDyg=zeros(n+m,n_xy);
    D2yg=zeros(n+m,n_xy);
    %
    D2p=[0  0  0
         0  0  0
         0  0  0
         2  0  0
         0  1  0
         0  0  2];
    for i_x=1:n_xy
       p = [1; xy(i_x,:)'; ...
            xy(i_x,1).^2; xy(i_x,1).*xy(i_x,2); xy(i_x,2).^2];
       Dp=[0            0
           1            0
           0            1
           2*xy(i_x,1)  0
           xy(i_x,2)    xy(i_x,1)
           0            2*xy(i_x,2)];
       for i_DOI=1:n
          eval(Cor2);
          Dxr(i_DOI,1)=Dr(1,1);  Dyr(i_DOI,1)=Dr(2,1);
          D2xr(i_DOI,1)=D2r(1,1);  DxDyr(i_DOI,1)=D2r(2,1);
          D2yr(i_DOI,1)=D2r(3,1);
       end
       %
       g(:,i_x)  = [ r ; p ];
       Dxg(:,i_x) = [ Dxr ; Dp(:,1) ];
       Dyg(:,i_x) = [ Dyr ; Dp(:,2) ];
       D2xg(:,i_x) = [ D2xr ; D2p(:,1) ];
       DxDyg(:,i_x) = [ DxDyr ; D2p(:,2) ];
       D2yg(:,i_x) = [ D2yr ; D2p(:,3) ];
    end
    %
    %
    case 3
    m=10;
    P=zeros(n,m);  R=zeros(n,n);
    for i_DOI=1:n
       P(i_DOI,:)=[ 1 Coord_DOI(i_DOI,:) Coord_DOI(i_DOI,1).^2 ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2) Coord_DOI(i_DOI,2).^2 ...
       Coord_DOI(i_DOI,1).^3  Coord_DOI(i_DOI,1).^2*Coord_DOI(i_DOI,2) ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2).^2  Coord_DOI(i_DOI,2).^3 ];
       for j_DOI=1:n
          eval(Cor1);
       end
    end
    det_R=det(R);
    if det_R>0.01
       disp( ['det(R)=', num2str(det_R),' is NOT okay'] )
       error('Theta is too large!!');
    end
    G=[ R   P
        P'  zeros(m,m)];
    clear R P i_DOI j_DOI
    %
    n_xy=size(xy,1);
    r=zeros(n,1);
    Dxr=zeros(n,1);  Dyr=zeros(n,1);
    D2xr=zeros(n,1);  DxDyr=zeros(n,1);
    D2yr=zeros(n,1);
    %
    g=zeros(n+m,n_xy);
    Dxg=zeros(n+m,n_xy);  Dyg=zeros(n+m,n_xy);
    D2xg=zeros(n+m,n_xy);  DxDyg=zeros(n+m,n_xy);
    D2yg=zeros(n+m,n_xy);
    %
    for i_x=1:n_xy
       p = [1; xy(i_x,:)'; ...
            xy(i_x,1).^2; xy(i_x,1).*xy(i_x,2); xy(i_x,2).^2; ...
            xy(i_x,1).^3; xy(i_x,1).^2.*xy(i_x,2); ...
            xy(i_x,1).*xy(i_x,2).^2; xy(i_x,2).^3 ];  %  Basis function
       Dp=[0                      0
           1                      0
           0                      1
           2*xy(i_x,1)            0
           xy(i_x,2)              xy(i_x,1)
           0                      2*xy(i_x,2)
           3*xy(i_x,1)^2          0
           2*xy(i_x,1)*xy(i_x,2)  xy(i_x,1)^2
           xy(i_x,2)^2            2*xy(i_x,1)*xy(i_x,2)
           0                      3*xy(i_x,2)^2 ];
       D2p=[ 0            0            0
             0            0            0
             0            0            0
             2            0            0
             0            1            0
             0            0            2
             6*xy(i_x,1)  0            0
             2*xy(i_x,2)  2*xy(i_x,1)  0
             0            2*xy(i_x,2)  2*xy(i_x,1)
             0            0            6*xy(i_x,2) ];
       for i_DOI=1:n
          eval(Cor2);
          Dxr(i_DOI,1)=Dr(1,1);  Dyr(i_DOI,1)=Dr(2,1);
          D2xr(i_DOI,1)=D2r(1,1);  DxDyr(i_DOI,1)=D2r(2,1);
          D2yr(i_DOI,1)=D2r(3,1);
       end
       %
       g(:,i_x)  = [ r ; p ];
       Dxg(:,i_x) = [ Dxr ; Dp(:,1) ];
       Dyg(:,i_x) = [ Dyr ; Dp(:,2) ];
       D2xg(:,i_x) = [ D2xr ; D2p(:,1) ];
       DxDyg(:,i_x) = [ DxDyr ; D2p(:,2) ];
       D2yg(:,i_x) = [ D2yr ; D2p(:,3) ];
    end
    %
    %
    case 4
    m=15;
    P=zeros(n,m);  R=zeros(n,n);
    for i_DOI=1:n
       P(i_DOI,:)=[ 1 Coord_DOI(i_DOI,:) Coord_DOI(i_DOI,1).^2 ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2) Coord_DOI(i_DOI,2).^2 ...
       Coord_DOI(i_DOI,1).^3  Coord_DOI(i_DOI,1).^2*Coord_DOI(i_DOI,2) ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2).^2  Coord_DOI(i_DOI,2).^3 ...
       Coord_DOI(i_DOI,1).^4  Coord_DOI(i_DOI,1).^3*Coord_DOI(i_DOI,2) ...
       Coord_DOI(i_DOI,1).^2*Coord_DOI(i_DOI,2).^2 ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2).^3  Coord_DOI(i_DOI,2).^4 ];
       for j_DOI=1:n
          eval(Cor1);
       end
    end
    det_R=det(R);
    if det_R>0.01
       disp( ['det(R)=', num2str(det_R),' is NOT okay'] )
       error('Theta is too large!!');
    end
    G=[ R   P
        P'  zeros(m,m)];
    clear R P i_DOI j_DOI
    %
    n_xy=size(xy,1);
    r=zeros(n,1);
    Dxr=zeros(n,1);  Dyr=zeros(n,1);
    D2xr=zeros(n,1);  DxDyr=zeros(n,1);
    D2yr=zeros(n,1);
    %
    g=zeros(n+m,n_xy);
    Dxg=zeros(n+m,n_xy);  Dyg=zeros(n+m,n_xy);
    D2xg=zeros(n+m,n_xy);  DxDyg=zeros(n+m,n_xy);
    D2yg=zeros(n+m,n_xy);
    %
    for i_x=1:n_xy
       p = [1; xy(i_x,:)'; ...
            xy(i_x,1).^2; xy(i_x,1).*xy(i_x,2); xy(i_x,2).^2; ...
            xy(i_x,1).^3; xy(i_x,1).^2.*xy(i_x,2); xy(i_x,1).*xy(i_x,2).^2; ...
            xy(i_x,2).^3; xy(i_x,1).^4; xy(i_x,1).^3.*xy(i_x,2); ...
            xy(i_x,1).^2.*xy(i_x,2).^2; xy(i_x,1).*xy(i_x,2).^3; xy(i_x,2).^4 ];  %  Basis function
       Dp=[0                      0
           1                      0
           0                      1
           2*xy(i_x,1)            0
           xy(i_x,2)              xy(i_x,1)
           0                      2*xy(i_x,2)
           3*xy(i_x,1)^2          0
           2*xy(i_x,1)*xy(i_x,2)  xy(i_x,1)^2
           xy(i_x,2)^2            2*xy(i_x,1)*xy(i_x,2)
           0                      3*xy(i_x,2)^2
           4*xy(i_x,1)^3            0
           3*xy(i_x,1)^2*xy(i_x,2)  xy(i_x,1)^3
           2*xy(i_x,1)*xy(i_x,2)^2  2*xy(i_x,1)^2*xy(i_x,2)
           xy(i_x,2)^3              3*xy(i_x,1)*xy(i_x,2)^2
           0                        4*xy(i_x,2)^3   ];
       D2p=[ 0            0            0
             0            0            0
             0            0            0
             2            0            0
             0            1            0
             0            0            2
             6*xy(i_x,1)  0            0
             2*xy(i_x,2)  2*xy(i_x,1)  0
             0            2*xy(i_x,2)  2*xy(i_x,1)
             0            0            6*xy(i_x,2)
               12*xy(i_x,1)^2         0                      0
               6*xy(i_x,1)*xy(i_x,2)  3*xy(i_x,1)^2          0
               2*xy(i_x,2)^2          4*xy(i_x,1)*xy(i_x,2)  2*xy(i_x,1)^2
               0                      3*xy(i_x,2)^2          6*xy(i_x,1)*xy(i_x,2)
               0                      0                      12*xy(i_x,2)^2  ];
       for i_DOI=1:n
          eval(Cor2);
          Dxr(i_DOI,1)=Dr(1,1);  Dyr(i_DOI,1)=Dr(2,1);
          D2xr(i_DOI,1)=D2r(1,1);  DxDyr(i_DOI,1)=D2r(2,1);
          D2yr(i_DOI,1)=D2r(3,1);
       end
       %
       g(:,i_x)  = [ r ; p ];
       Dxg(:,i_x) = [ Dxr ; Dp(:,1) ];
       Dyg(:,i_x) = [ Dyr ; Dp(:,2) ];
       D2xg(:,i_x) = [ D2xr ; D2p(:,1) ];
       DxDyg(:,i_x) = [ DxDyr ; D2p(:,2) ];
       D2yg(:,i_x) = [ D2yr ; D2p(:,3) ];
    end
    %
    %
    case 5
    m=4;
    P=zeros(n,m);  R=zeros(n,n);
    for i_DOI=1:n
       P(i_DOI,:)=[ 1 Coord_DOI(i_DOI,:) ...
                    Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2) ];
       for j_DOI=1:n
          eval(Cor1);
       end
    end
    det_R=det(R);
    if det_R>0.01
       disp( ['det(R)=', num2str(det_R),' is NOT okay'] )
       error('Theta is too large!!');
    end
    G=[ R   P
        P'  zeros(m,m)];
    clear R P i_DOI j_DOI
    %
    n_xy=size(xy,1);
    r=zeros(n,1);
    Dxr=zeros(n,1);  Dyr=zeros(n,1);
    D2xr=zeros(n,1);  DxDyr=zeros(n,1);
    D2yr=zeros(n,1);
    %
    g=zeros(n+m,n_xy);
    Dxg=zeros(n+m,n_xy);  Dyg=zeros(n+m,n_xy);
    D2xg=zeros(n+m,n_xy);  DxDyg=zeros(n+m,n_xy);
    D2yg=zeros(n+m,n_xy);
    %
    D2p=[0  0  0
         0  0  0
         0  0  0
         0  1  0 ];
    for i_x=1:n_xy
       p =[ 1; xy(i_x,:)'; xy(i_x,1).*xy(i_x,2) ];  %  Basis function
       Dp=[ 0          0
            1          0
            0          1
            xy(i_x,2)  xy(i_x,1) ];
       for i_DOI=1:n
          eval(Cor2);
          Dxr(i_DOI,1)=Dr(1,1);  Dyr(i_DOI,1)=Dr(2,1);
          D2xr(i_DOI,1)=D2r(1,1);  DxDyr(i_DOI,1)=D2r(2,1);
          D2yr(i_DOI,1)=D2r(3,1);
       end
       %
       g(:,i_x)  = [ r ; p ];
       Dxg(:,i_x) = [ Dxr ; Dp(:,1) ];
       Dyg(:,i_x) = [ Dyr ; Dp(:,2) ];
       D2xg(:,i_x) = [ D2xr ; D2p(:,1) ];
       DxDyg(:,i_x) = [ DxDyr ; D2p(:,2) ];
       D2yg(:,i_x) = [ D2yr ; D2p(:,3) ];
    end
    %
    %
    case 6
    m=9;
    P=zeros(n,m);  R=zeros(n,n);
    for i_DOI=1:n
       P(i_DOI,:)=[ 1 Coord_DOI(i_DOI,:) Coord_DOI(i_DOI,1).^2 ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2) Coord_DOI(i_DOI,2).^2 ...
       Coord_DOI(i_DOI,1).^2*Coord_DOI(i_DOI,2) Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2).^2 ...
       Coord_DOI(i_DOI,1).^2*Coord_DOI(i_DOI,2).^2 ];
       for j_DOI=1:n
          eval(Cor1);
       end
    end
    det_R=det(R);
    if det_R>0.01
       disp( ['det(R)=', num2str(det_R),' is NOT okay'] )
       error('Theta is too large!!');
    end
    G=[ R   P
        P'  zeros(m,m)];
    clear R P i_DOI j_DOI
    %
    n_xy=size(xy,1);
    r=zeros(n,1);
    Dxr=zeros(n,1);  Dyr=zeros(n,1);
    D2xr=zeros(n,1);  DxDyr=zeros(n,1);
    D2yr=zeros(n,1);
    %
    g=zeros(n+m,n_xy);
    Dxg=zeros(n+m,n_xy);  Dyg=zeros(n+m,n_xy);
    D2xg=zeros(n+m,n_xy);  DxDyg=zeros(n+m,n_xy);
    D2yg=zeros(n+m,n_xy);
    %
    for i_x=1:n_xy
       p =[ 1; xy(i_x,:)'; xy(i_x,1).^2; xy(i_x,1).*xy(i_x,2); xy(i_x,2).^2; ...
           xy(i_x,1).^2.*xy(i_x,2); xy(i_x,1).*xy(i_x,2).^2; ...
           xy(i_x,1).^2.*xy(i_x,2).^2 ];
       Dp=[ 0            0
            1            0
            0            1
            2*xy(i_x,1)  0
            xy(i_x,2)    xy(i_x,1)
            0            2*xy(i_x,2)
            2*xy(i_x,1)*xy(i_x,2)    xy(i_x,1)^2
            xy(i_x,2)^2              2*xy(i_x,1)*xy(i_x,2)
            2*xy(i_x,1)*xy(i_x,2)^2  2*xy(i_x,1)^2*xy(i_x,2) ];
       D2p=[ 0  0  0
             0  0  0
             0  0  0
             2  0  0
             0  1  0
             0  0  2
             2*xy(i_x,2)    2*xy(i_x,1)            0
             0              2*xy(i_x,2)            2*xy(i_x,1)
             2*xy(i_x,2)^2  4*xy(i_x,1)*xy(i_x,2)  2*xy(i_x,1)^2 ];
       for i_DOI=1:n
          eval(Cor2);
          Dxr(i_DOI,1)=Dr(1,1);  Dyr(i_DOI,1)=Dr(2,1);
          D2xr(i_DOI,1)=D2r(1,1);  DxDyr(i_DOI,1)=D2r(2,1);
          D2yr(i_DOI,1)=D2r(3,1);
       end
       %
       g(:,i_x)  = [ r ; p ];
       Dxg(:,i_x) = [ Dxr ; Dp(:,1) ];
       Dyg(:,i_x) = [ Dyr ; Dp(:,2) ];
       D2xg(:,i_x) = [ D2xr ; D2p(:,1) ];
       DxDyg(:,i_x) = [ DxDyr ; D2p(:,2) ];
       D2yg(:,i_x) = [ D2yr ; D2p(:,3) ];
    end
    %
    %
    case 7
    m=16;
    P=zeros(n,m);  R=zeros(n,n);
    for i_DOI=1:n
       P(i_DOI,:)=[ 1 Coord_DOI(i_DOI,:) Coord_DOI(i_DOI,1).^2 ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2) Coord_DOI(i_DOI,2).^2 ...
       Coord_DOI(i_DOI,1).^3  Coord_DOI(i_DOI,1).^2*Coord_DOI(i_DOI,2) ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2).^2  Coord_DOI(i_DOI,2).^3 ...
       Coord_DOI(i_DOI,1).^3*Coord_DOI(i_DOI,2)  Coord_DOI(i_DOI,1).^2*Coord_DOI(i_DOI,2).^2 ...
       Coord_DOI(i_DOI,1)*Coord_DOI(i_DOI,2).^3  Coord_DOI(i_DOI,1).^3*Coord_DOI(i_DOI,2).^2 ...
       Coord_DOI(i_DOI,1).^2*Coord_DOI(i_DOI,2).^3  Coord_DOI(i_DOI,1).^3*Coord_DOI(i_DOI,2).^3 ];
       for j_DOI=1:n
          eval(Cor1);
       end
    end
    det_R=det(R);
    if det_R>0.01
       disp( ['det(R)=', num2str(det_R),' is NOT okay'] )
       error('Theta is too large!!');
    end
    G=[ R   P
        P'  zeros(m,m)];
    clear R P i_DOI j_DOI
    %
    n_xy=size(xy,1);
    r=zeros(n,1);
    Dxr=zeros(n,1);  Dyr=zeros(n,1);
    D2xr=zeros(n,1);  DxDyr=zeros(n,1);
    D2yr=zeros(n,1);
    %
    g=zeros(n+m,n_xy);
    Dxg=zeros(n+m,n_xy);  Dyg=zeros(n+m,n_xy);
    D2xg=zeros(n+m,n_xy);  DxDyg=zeros(n+m,n_xy);
    D2yg=zeros(n+m,n_xy);
    %
    for i_x=1:n_xy
       p = [1; xy(i_x,:)'; xy(i_x,1).^2; xy(i_x,1).*xy(i_x,2); xy(i_x,2).^2; ...
            xy(i_x,1).^3; xy(i_x,1).^2.*xy(i_x,2); ...
            xy(i_x,1).*xy(i_x,2).^2; xy(i_x,2).^3; ...
            xy(i_x,1).^3.*xy(i_x,2); xy(i_x,1).^2.*xy(i_x,2).^2; ...
            xy(i_x,1).*xy(i_x,2).^3; xy(i_x,1).^3.*xy(i_x,2).^2; ...
            xy(i_x,1).^2.*xy(i_x,2).^3; xy(i_x,1).^3.*xy(i_x,2).^3 ];  %  Basis function
       Dp=[0                          0
           1                          0
           0                          1
           2*xy(i_x,1)                0
           xy(i_x,2)                  xy(i_x,1)
           0                          2*xy(i_x,2)
           3*xy(i_x,1)^2              0
           2*xy(i_x,1)*xy(i_x,2)      xy(i_x,1)^2
           xy(i_x,2)^2                2*xy(i_x,1)*xy(i_x,2)
           0                          3*xy(i_x,2)^2 
           3*xy(i_x,1)^2*xy(i_x,2)    xy(i_x,1)^3
           2*xy(i_x,1)*xy(i_x,2)^2    2*xy(i_x,1)^2*xy(i_x,2)
           xy(i_x,2)^3                3*xy(i_x,1)*xy(i_x,2)^2
           3*xy(i_x,1)^2*xy(i_x,2)^2  2*xy(i_x,1)^3*xy(i_x,2)
           2*xy(i_x,1)*xy(i_x,2)^3    3*xy(i_x,1)^2*xy(i_x,2)^2
           3*xy(i_x,1)^2*xy(i_x,2)^3  3*xy(i_x,1)^3*xy(i_x,2)^2  ];
       D2p=[ 0            0            0
             0            0            0
             0            0            0
             2            0            0
             0            1            0
             0            0            2
             6*xy(i_x,1)  0            0
             2*xy(i_x,2)  2*xy(i_x,1)  0
             0            2*xy(i_x,2)  2*xy(i_x,1)
             0            0            6*xy(i_x,2)
             6*xy(i_x,1)*xy(i_x,2)    3*xy(i_x,1)^2              0
             2*xy(i_x,2)^2            4*xy(i_x,1)*xy(i_x,2)      2*xy(i_x,1)^2
             0                        3*xy(i_x,2)^2              6*xy(i_x,1)*xy(i_x,2)
             6*xy(i_x,1)*xy(i_x,2)^2  6*xy(i_x,1)^2*xy(i_x,2)    2*xy(i_x,1)^3
             2*xy(i_x,2)^3            6*xy(i_x,1)*xy(i_x,2)^2    6*xy(i_x,1)^2*xy(i_x,2)
             6*xy(i_x,1)*xy(i_x,2)^3  9*xy(i_x,1)^2*xy(i_x,2)^2  6*xy(i_x,1)^3*xy(i_x,2) ];
       for i_DOI=1:n
          eval(Cor2);
          Dxr(i_DOI,1)=Dr(1,1);  Dyr(i_DOI,1)=Dr(2,1);
          D2xr(i_DOI,1)=D2r(1,1);  DxDyr(i_DOI,1)=D2r(2,1);
          D2yr(i_DOI,1)=D2r(3,1);
       end
       %
       g(:,i_x)  = [ r ; p ];
       Dxg(:,i_x) = [ Dxr ; Dp(:,1) ];
       Dyg(:,i_x) = [ Dyr ; Dp(:,2) ];
       D2xg(:,i_x) = [ D2xr ; D2p(:,1) ];
       DxDyg(:,i_x) = [ DxDyr ; D2p(:,2) ];
       D2yg(:,i_x) = [ D2yr ; D2p(:,3) ];
    end
    %
    %
    otherwise
    error('Wrong polynomial order! \n');
end
%
clear i_x i_DOI Dr D2r r Dxr Dp Dyr D2xr D2p DxDyr D2yr
clear Coord_DOI xy
All_g = [g Dxg Dyg D2xg DxDyg D2yg];
clear g Dxg Dyg D2xg DxDyg D2yg
All_PHI=G\All_g;  All_PHI=All_PHI';
Del_PHI=(size(All_PHI,2)-size(p,1)+1):size(All_PHI,2);
All_PHI(:,Del_PHI)=[];
%
i_PHI=size(All_PHI,1)/6;
PHI=All_PHI(1:i_PHI,:);
%
Sum_PHI=mean(sum(PHI'));
switch P_order
   case {1, 4}
   if abs(Sum_PHI - 1) > 1E-9
       disp( ['Sum of PHI - 1=', num2str(Sum_PHI-1),' is OKAY'] )
       error('Theta is too small!!');
   end
   case 2
   if abs(Sum_PHI - 1) > 1E-8
       disp( ['Sum of PHI - 1=', num2str(Sum_PHI-1),' is OKAY'] )
       error('Theta is too small!!');
   end
   case {3, 5, 6, 7}
   if abs(Sum_PHI - 1) > 1E-7
       disp( ['Sum of PHI - 1=', num2str(Sum_PHI-1),' is OKAY'] )
       error('Theta is too small!!');
   end
   otherwise
    error('Wrong polynomial order! \n');
end
%
DxPHI=All_PHI(i_PHI+1:2*i_PHI,:);
DyPHI=All_PHI(2*i_PHI+1:3*i_PHI,:);
D2xPHI=All_PHI(3*i_PHI+1:4*i_PHI,:);
DxDyPHI=All_PHI(4*i_PHI+1:5*i_PHI,:);
D2yPHI=All_PHI(5*i_PHI+1:6*i_PHI,:);
