function [xipb, vipb] = Line_integr (x1,x2,order)

%  function [xipb, vipb] = Line_integr (x1,x2,order)
%
%  Determining the positions of gaussian integration points and 
%  their weights and the jacobian determinant for a line
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 8 March 2005
%
%  Input
%  x1, x2:  Column vectors containing coordinates of two
%           connected boundary nodes
%  order:  The order of gaussian numerical integration rule to be employed
%        
%  Output
%  xipb:  A matrix of order 2 x (order) containing coordinates of 
%         the gaussian sampling points
%  vipb:  A row vector of order 1 x (order) containing Jacobian
%         determinants multiplied by the weights
%
%  Reference:
%  Pudjisuryadi (2001), AIT Thesis No. ST-01-8
%
if x1(1)>x2(1)
    xt=x2;   x2=x1;  x1=xt;
elseif x1(1)==x2(1)
    if x1(2)>x2(2)
        xt=x2;   x2=x1;  x1=xt;
    end
end
%
[gpts, gwts]=Gaussq(order);
%
Nb=0.5*[ 1-gpts' 1+gpts' ];
DNb=ones(order,2);
DNb(:,1)=-1;
DNb=0.5*DNb;
xipb=zeros(2,order);

if x1(2)==x2(2)
    %  Horizontal case
    xipb(1,:)=(Nb*[x1(1); x2(1)])';
    xipb(2,:)=x1(2);
    Jb=(DNb*[x1(1); x2(1)])';
    vipb=gwts.*Jb;
elseif x1(1)==x2(1)  
    %  Vertical case
    xipb(1,:)=x1(1);
    xipb(2,:)=(Nb*[x1(2); x2(2)])';
    Jb=(DNb*[x1(2); x2(2)])';
    vipb=gwts.*Jb;
else
    %  Aslant case
    m=(x2(2)-x1(2))/(x2(1)-x1(1));
    ratio = norm(x2-x1)/(x2(1)-x1(1));
    xhor=(Nb*[x1(1); x2(1)])';
    if m>0
        xipb(1,:)= xhor;
        xipb(2,:) = (xhor-x1(1))*m + x1(2);
    elseif m<0
        xipb(1,:)=xhor;
        xipb(2,:) = x1(2) - (xhor-x1(1))*m;
    end
    Jb=(DNb*[x1(1); x2(1)])';
    vipb=ratio*(gwts.*Jb);            
end 