function  [Moments, Shears] = Moment_Shear_fun( Ielem, Lnods, Coord, IMatno, Props, Cor_type, ...
                                                theta, P_order, Nodes, n_Nodes, Ndofn, Xdisp, AuG)

%  [Moments, Shears] = Moment_Shear_fun( Ielem, Lnods, Coord, IMatno, Props, Cor_type, ...
%                                        theta, P_order, Nodes, n_Nodes, Ndofn, Xdisp)
%
%  To calculate bending and twisting moments 
%  and shear forces using the shear strains
%  for a kriging plate bending element 
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 13 March 2006
%  Modification: 15 April 2021 by Sebastian (MITC3+)
%
%  Input
%  Ielem:  Current element number
%  Lnods:  Element node numbers listed per each element
%  Coord:  Coordinate of the nodes
%  IMatno: Current material property number
%  Props:  Elastic modulus, Poisson's ratio, material thickness
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%  theta:  The correlation parameter
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%  Nodes  : Node numbers in an influence domain
%  n_Nodes: Number of nodes in the influence domain
%  Ndofn:  Number of degrees of freedom per nodal point
%  Xdisp:  Displacements at nodes
%
%  Output
%  Moments:  (Mxx Myy Mxy)' at the vertices
%  Shears :  (Qxz Qyz)' at the vertices
%

%  Identify the displacements of the element nodal points
%  ---> Eldis
I_dof = Global_dof (Nodes, n_Nodes, Ndofn);
Eldis=Xdisp(I_dof,:);
clear I_dof
%
%  Nodal coordinates in the influence domain
%
Coord_DOI=Coord(Nodes,:);  
% clear Nodes
d_max = Max_Distance( Coord_DOI);
TRI_coord=Coord(Lnods(Ielem,:),:);
%
%  Transforming to natural coordinates
%
[Nat_Coord_DOI] = Natural( Coord_DOI, TRI_coord);
%
%  Kriging shape functions and their derivatives
%
Nat_TRI_coord = [0  0;  1   0;  0   1];
[PHI, Nat_DxPHI, Nat_DyPHI] = ...
 Kriging_shapef( Nat_Coord_DOI, theta, d_max, P_order, Nat_TRI_coord, Cor_type);
clear Nat_Coord_DOI Coord_DOI Nat_TRI_coord d_max
%
%  Transforming Natural Dx & Dy Phi Using Inverse Jacobian
%
[DxPHI, DyPHI] = NaturalDxDy( Nat_DxPHI, Nat_DyPHI, TRI_coord);
clear Nat_DxPHI Nat_DyPHI 
%
%  Plate constitutive matrices
%
[Db, Ds] = Modps(IMatno, Props);
%
%  Transform the rotation variables to nodal rotations
%
T=sparse(zeros(Ndofn*n_Nodes, Ndofn*n_Nodes));
for i_Es0=1:n_Nodes
    T(3*i_Es0-2, 3*i_Es0-2)= 1;
    T(3*i_Es0-1, 3*i_Es0)= 1;
    T(3*i_Es0, 3*i_Es0-1)= -1;   
end
Eldis=T*Eldis;
%
%  Bending and twisting moments and shear forces MITC3+
%
Nsamp=size(Lnods,2);  %  Sampling points for this case = vertices of the triangle
Moments = zeros(3,Nsamp);  Shears = zeros(2,Nsamp);
for Isamp=1:Nsamp
   [N, DN, C, S, L, A] = MITC_shape_f (TRI_coord, TRI_coord(Isamp,:));
   [Shape1, Shape2, Bbdltb, Bbb, Bsdltb, Bsb] = Shape_fun_MITC3(N, DN, TRI_coord, PHI(Isamp,:), DxPHI(Isamp,:), DyPHI(Isamp,:), ...
                                C, S, A, n_Nodes,L, Nodes, Lnods(Ielem,:));
    Bb=Bbb+Bbdltb*AuG;                   %Condensation
    Bs=Bsb+Bsdltb*AuG;                   %Aug masih dihasilkan dari integration sampling point
    Moments(:,Isamp) = Db*Bb*Eldis;
    Shears(:,Isamp) = Ds*Bs*Eldis;
end