function  [Moments, Shears] = Moment_Shear_fun3( Ielem, Lnods, Coord, IMatno, Props, Cor_type, ...
                                                theta, P_order, Nodes, n_Nodes, Ndofn, Xdisp)

%  [Moments, Shears] = Moment_Shear_fun3( Ielem, Lnods, Coord, IMatno, Props, Cor_type, ...
%                                        theta, P_order, Nodes, n_Nodes, Ndofn, Xdisp)
%
%  To calculate bending and twisting moments 
%  and shear forces using kriging from nodal rotations
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 13 March 2006
%  Modification: 15 March 2006
%
%  Input
%  Ielem:  Current element number
%  Lnods:  Element node numbers listed per each element
%  Coord:  Coordinate of the nodes
%  IMatno: Current material property number
%  Props:  Elastic modulus, Poisson's ratio, material thickness
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%  theta:  The correlation parameter
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%  Nodes  : Node numbers in an influence domain
%  n_Nodes: Number of nodes in the influence domain
%  Ndofn:  Number of degrees of freedom per nodal point
%  Xdisp:  Displacements at nodes
%
%  Output
%  Moments:  (Mxx Myy Mxy)' at the vertices
%  Shears :  (Qxz Qyz)' at the vertices
%

%  Identify the displacements of the element nodal points
%  ---> Eldis
I_dof = Global_dof (Nodes, n_Nodes, Ndofn);
Eldis=Xdisp(I_dof,:);
clear I_dof
%
%  Nodal coordinates in the influence domain
%
Coord_DOI=Coord(Nodes,:);  clear Nodes
d_max = Max_Distance( Coord_DOI);
%
%  Kriging shape functions and their derivatives
%
TRI_coord=Coord(Lnods(Ielem,:),:);
[PHI, DxPHI, DyPHI, D2xPHI, DxDyPHI, D2yPHI] = ...
 Kriging_shapef2( Coord_DOI, theta, d_max, P_order, TRI_coord, Cor_type);
clear Coord_DOI d_max TRI_coord
%
%  Plate constitutive matrices
%
Db = Modps(IMatno, Props);
E=Props(IMatno,1);  nu=Props(IMatno,2);
h=Props(IMatno,3); clear Props
%
%  Transform the rotation variables to nodal rotations
%
T=sparse(zeros(Ndofn*n_Nodes, Ndofn*n_Nodes));
for i_Es0=1:n_Nodes
    T(3*i_Es0-2, 3*i_Es0-2)= 1;
    T(3*i_Es0-1, 3*i_Es0)= -1;
    T(3*i_Es0, 3*i_Es0-1)= 1;
end
Eldis=T*Eldis;
%
%  Bending and twisting moments
%
Nsamp=size(Lnods,2);  %  Sampling points for this case = vertices of the triangle
Moments = zeros(3,Nsamp);
for Isamp=1:Nsamp
   [Shape, Bb] = Shape_fun(PHI(Isamp,:), DxPHI(Isamp,:), DyPHI(Isamp,:), n_Nodes);
   Moments(:,Isamp) = -Db*Bb*Eldis;
end
%
%  Shear Forces
%
dof=Ndofn*n_Nodes;
psi_x=Eldis( 2:3:(dof-1), 1);  psi_y=Eldis( 3:3:dof, 1);
Db=E*h^3/12/(1-nu^2);
Shears= -Db*[ ( D2xPHI*psi_x + 0.5*(1-nu)*D2yPHI*psi_x + ...
                0.5*(1+nu)*DxDyPHI*psi_y )'
              ( D2yPHI*psi_y + 0.5*(1-nu)*D2xPHI*psi_y + ...
                0.5*(1+nu)*DxDyPHI*psi_x )' ];