function  Moments = Moment_fun( Ielem, Lnods, Coord, IMatno, Props, Cor_type, ...
                               theta, P_order, Nodes, n_Nodes, Ndofn, Xdisp)

%  Moments = Moment_fun( Ielem, Lnods, Coord, IMatno, Props, Cor_type, ...
%                       theta, P_order, Nodes, n_Nodes, Ndofn, Xdisp)
%
%  To calculate bending and twisting moments 
%  for a kriging plate bending element
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 13 March 2006
%  Modification:
%
%  Input
%  Ielem:  Current element number
%  Lnods:  Element node numbers listed per each element
%  Coord:  Coordinate of the nodes
%  IMatno: Current material property number
%  Props:  Elastic modulus, Poisson's ratio, material thickness
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%  theta:  The correlation parameter
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%  Nodes  : Node numbers in an influence domain
%  n_Nodes: Number of nodes in the influence domain
%  Ndofn:  Number of degrees of freedom per nodal point
%  Xdisp:  Displacements at nodes
%
%  Output
%  Moments:  (Mxx Myy Mxy)' at the vertices
%

%  Identify the displacements of the element nodal points
%  ---> Eldis
I_dof = Global_dof (Nodes, n_Nodes, Ndofn);
Eldis=Xdisp(I_dof,:);
clear I_dof
%
%  Nodal coordinates in the influence domain
%
Coord_DOI=Coord(Nodes,:);  clear Nodes
d_max = Max_Distance( Coord_DOI);
%
%  Kriging shape functions and their derivatives
%
TRI_coord=Coord(Lnods(Ielem,:),:);
[PHI, DxPHI, DyPHI] = ...
 Kriging_shapef( Coord_DOI, theta, d_max, P_order, TRI_coord, Cor_type);
clear Coord_DOI d_max TRI_coord
%
%  Plate constitutive matrices
%
[Db, Ds] = Modps(IMatno, Props);
clear Ds
%
%  Transformation matrix for 
%  changing the rotation variables to nodal rotations
%
T=sparse(zeros(Ndofn*n_Nodes, Ndofn*n_Nodes));
for i_Es0=1:n_Nodes
    T(3*i_Es0-2, 3*i_Es0-2)= 1;
    T(3*i_Es0-1, 3*i_Es0)= -1;
    T(3*i_Es0, 3*i_Es0-1)= 1;
end
%
%  Bending and twisting moments
%
Nsamp=size(Lnods,2);  %  Sampling points for this case = vertices of the triangle
Moments = zeros(3,Nsamp);
for Isamp=1:Nsamp
   [Shape, Bb] = Shape_fun(PHI(Isamp,:), DxPHI(Isamp,:), DyPHI(Isamp,:), n_Nodes);
   Moments(:,Isamp) = -Db*Bb*T*Eldis;
end
