function [DxPHI, DyPHI] = NaturalDxDy( Nat_DxPHI, Nat_DyPHI, TRI_coord)

%  [xip, vip, rs] = Tri_integral (xp1,xp2,xp3, Nsamp)
%
%  To return the positions of integration points and 
%  their weights for a triangular element
%  using Nsamp-point formula
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 7 March 2005
%  Extension:  30 August 2005, 9 Feb 2006
%
%  Input
%  xp1, xp2, xp3:  column vectors containing coordinates of the vertices
%  Nsamp:  the number of sampling points for the integration
%          of the triangular elements (1,3,4,6,7,12,13)
%
%  Output
%  xip:  a matrix of order 2xNsamp containing coordinates of the sampling
%        points
%  vip:  a row vector of order 1xNsamp containing one half of Jacobian
%        determinants multiplied by the weights
%  rs:  a matrix of order 2xNsamp containing coordinates of the sampling
%        points in natural coordinate
%
%  Reference:
%  Plengkhom, K., 2005.  EFEM Computer Program (in Fortran 95)
%  Cook, R.D. et al., 2002.  Concepts and Applications of FEA
%
%  xi:  Position of the sampling points expressed in area coordinate

%  Jacobian matrix
x1=TRI_coord(1,1);  y1=TRI_coord(1,2);
x2=TRI_coord(2,1);  y2=TRI_coord(2,2);
x3=TRI_coord(3,1);  y3=TRI_coord(3,2);
a=x2-x1;    b=y2-y1;
c=y3-y1;    d=x3-x1;
J=[a b; d c];

%  Modifying into 1 line & transforming
n_samp=size(Nat_DxPHI,1);    n_DOI=size(Nat_DxPHI,2);
Mod_Nat_DxPHI=[];   Mod_Nat_DyPHI=[];
for i=1:n_samp
    Mod_Nat_DxPHI=[Mod_Nat_DxPHI    Nat_DxPHI(i,:)];
    Mod_Nat_DyPHI=[Mod_Nat_DyPHI    Nat_DyPHI(i,:)];
end
Mod_Nat_DxDy=[Mod_Nat_DxPHI; Mod_Nat_DyPHI];
Mod_DxDy=J\Mod_Nat_DxDy;

%  Returning to previous matrix size
DxPHI=zeros(n_samp,n_DOI);
DyPHI=zeros(n_samp,n_DOI);
for i=1:n_samp
    DxPHI(i,:)=Mod_DxDy(1,(i-1)*n_DOI+1:i*n_DOI);
    DyPHI(i,:)=Mod_DxDy(2,(i-1)*n_DOI+1:i*n_DOI);
end

