function [R, DR, D2R] = R_Gauss (x, x_I, theta, d)

%  [R, DR, D2R] = R_Gauss (x, x_I, theta, d)
%
%  To evaluate the value of Gaussian 
%  correlation function and its derivatives
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 18 July 2005
%
%  Input
%  x:  vector of coordinate of a point of interest 
%      in the influence domain
%  x_I:  vector of nodal coordinate in the influence domain
%  theta:  parameter of gaussian correlation function
%  d:  distance to normalize the distance between x and x_I
%
%  Output
%  R:  value of the correlation function, R(x,x_I)
%  DR: column vector of the values
%      of the correlation function derivatives, 
%      dR/dx and dR/dy for (x,x_I)
%  D2R: column vector of the values
%       of the correlation function second derivatives,
%       d2R/dx2, d2R/dydx=d2R/dx/y and d2R/dy2 for (x,x_I)
%
%  Reference
%  Wong F.T. (2005).  'Ch3. Kriging Interpolation', 
%  AIT Dissertation Draft
%
r=norm(x-x_I);
R = exp(-(theta*r/d)^2);
DR(1,1) = -2*(theta/d)^2*(x(1)-x_I(1)) * exp(-(theta*r/d)^2);
D2R(1,1) = -2*(theta/d)^2*exp(-(theta*r/d)^2)* ...
           (1 - 2*(theta/d)^2 * (x(1)-x_I(1))^2 );
if length(x)>=2
   DR(2,1) = -2*(theta/d)^2*(x(2)-x_I(2)) * exp(-(theta*r/d)^2);
   D2R(2,1) = 4*(theta/d)^4*(x(1)-x_I(1))*(x(2)-x_I(2))* ...
              exp(-(theta*r/d)^2);
   D2R(3,1) = -2*(theta/d)^2*exp(-(theta*r/d)^2)* ...
           (1 - 2*(theta/d)^2 * (x(2)-x_I(2))^2 );
   if length(x)==3
      DR(3,1) = -2*(theta/d)^2*(x(3)-x_I(3)) * exp(-(theta*r/d)^2);
      % For the case of 3D NOT COMPLETE YET!!
   end
end
%
