function [w, Dw, D2w] = R_quartic (x, x_I, theta, d_max)
                          
% [w, Dw, D2w] = R_quartic (x, x_I, d_max)
%
%  Evaluates the values of the quartic spline
%  correlation function and its derivatives
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 4 October 2005
%  Adopted from w_quartic.m, 1 March, 16 April 2005 
%  (Use the term 'correlation function' instead of 
%    'weight function')
%
%  Input
%  x:  vector of coordinate of a point of interest 
%      in the influence domain
%  x_I:  vector of nodal coordinate in the influence domain
%  theta:  parameter of quartic correlation function
%  d_max:  diameter of the domain of influence (scalar)
%
%  Output
%  w:  value of the weight function, w(x,x_I)
%  Dw: column vector of the values
%      of the weight function derivatives, 
%      dw/dx and dw/dy for (x,x_I)
%  D2w: column vector of the values
%       of the weight function second derivatives,
%       d2w/dx2, d2w/dydx=d2w/dxdy and d2R/dy2 for (x,x_I)
%
%  References:
%  Kanok-Nukulchai et al. (2001). 'On elimination ...',
%  IJNME, 52, 705-725.
%  Pudjisuryadi (2002).  'MLS Approximation...', 
%  Dimensi Teknik Sipil, 4, 47-50.
%
h = norm(x-x_I);
d = theta*h/d_max;
if d<=1
   w = 1 - 6*d^2 + 8*d^3 - 3*d^4;
   if h~=0
      Dw(1,1)= theta*(-12*d + 24*d^2 - 12*d^3)/d_max * ...
               (x(1) - x_I(1) )/h;
      D2w(1,1)= theta^3*24*(1-d)*(x(1)-x_I(1))^2/h/d_max^3 - ...
                theta^2*12*(1-2*d+d^2)/d_max^2;
      if length(x)>=2
         Dw(2,1)= theta*(-12*d + 24*d^2 - 12*d^3)/d_max * ...
                  (x(2) - x_I(2))/h;
         D2w(2,1)= theta^3*24*(1-d)*(x(1)-x_I(1))*(x(2)-x_I(2))/h/d_max^3;
         D2w(3,1)= theta^3*24*(1-d)*(x(2)-x_I(2))^2/h/d_max^3 - ...
                   theta^2*12*(1-2*d+d^2)/d_max^2;
         if length(x)==3
            Dw(3,1)= theta*(-12*d + 24*d^2 - 12*d^3)/d_max * ...
                     (x(3) - x_I(3))/h;
          % For the case of 3D NOT COMPLETE YET!!
         end
      end
   else
      Dw=zeros(length(x),1);
      D2w = [ -theta^2*12/d_max^2;  0;  -theta^2*12/d_max^2 ];
   end
else
   w=0;
   Dw=zeros(2,1);
   D2w=zeros(3,1);
end