function [w, theta_x, theta_y] = SSH_U_Rectangle(X, Y, a, b, Props, q)

%  function [w, theta_x, theta_y] = SSH_U_Rectangle(X, Y, a, b, Props, q)
%
%  To evaluate the deflection and rotations of a 
%  SSH-U rectangular plate of the dimensions a X b at points (X,Y)
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 7 June 2006
%
%  Input
%  X and Y:  Matrices of x and y where the deflection and rotations 
%            are evaluated
%  a and b:  Lengths of the plate in x and y directions, respectively
%  Props:  Elastic modulus, Poisson's ratio, plate thickness
%  q:  Uniform load
%
%  Output
%  w:  Matrix of deflection at points (X,Y)
%  theta_x, theta_y:  Matrices of rotations about x and y axes,
%                     respectively, at points (X,Y)
%
%  Reference:  Reismann (1988)
%

E=Props(1,1);  nu=Props(1,2);  h=Props(1,3);
G=E/2/(1+nu); k=5/6;
%  Flexural rigidity
D=E*h^3/12/(1-nu^2);
%
w=zeros(size(X)); 
psi_x=zeros(size(X)); psi_y=zeros(size(X));
for m=1:2:43
    for n=1:2:43
      %  Deflection
%       w_old=w;
      M=m*pi/a;  N=n*pi/b;
      p_mn=16*q/pi^2/(m*n);
      w_bar=( 1/D/(M^2+N^2) + 1/(k*G*h) )* p_mn/(M^2+N^2)*sin(M*X).*sin(N*Y);
      w = w + w_bar;
%       Err_w=(w-w_old)./w;
      %  Rotation about y axis
%       psi_x_old=psi_x;
      psi_x_bar= -p_mn*M/D/(M^2+N^2)^2 *cos(M*X).*sin(N*Y);
      psi_x = psi_x + psi_x_bar;
%       Err_px=(psi_x-psi_x_old)./psi_x;
      %  Rotation about -x axis
%       psi_y_old=psi_y;
      psi_y_bar= -p_mn*N/D/(M^2+N^2)^2 *sin(M*X).*cos(N*Y);
      psi_y = psi_y + psi_y_bar;
%       Err_py=(psi_y-psi_y_old)./psi_y;
    end
end
theta_x= -psi_y;
theta_y= psi_x;