function [Shape1, Shape2, Bbdltb, Bbb, Bsdltb, Bsb] = Shape_fun_MITC3(N, DN, TRI_coord, Phi, DxPhi, DyPhi, ...
                                    C, S, A, n_Nodes, L, Nodes_I, Lnods)
 
%  Establishing shape function matrix and bending strain-displacement
%  matrices at sampling point for a MITC3+ plate element 
%
%  Written by Sebastian and Wong Foek Tjong
%  Petra Christian University, 15 April 2021
%
%  Input
%  TRI_coord: Nodal number of an element 
%  Phi:  Row matrix of shape function values at a sampling point (with Kriging)
%  DxPhi, DyPhi:  Row matrix of shape function derivatives 
%                 with respect to x and y, respectively, at a sampling point (with Kriging)
%  N:  matrix of standard shape function values at a sampling point for triagular element
%  C,S:  The cosinus and sinus direction of the triangle
%  A:  The area of the triangle
%  xi_Isamp: Coordinate of the sampling points in natural coordinate system
%  n_Nodes:  Number of nodes in an element
%
%  Output
%  Shape1:  The standard shape function matrix for plate
%  Shape2:  The higher order shape function matrix for for cubic bubble MITC3+ plate
%  Bbb:  The standard bending strain-displacement matrix for plate
%  Bbdltb:  The higher order bending strain-displacement matrix for cubic bubble MITC3+ plate
%  Bsb:  The higher order shear strain-displacement matrix for plate
%  Bsdltb:  The higher order shear strain-displacement matrix for cubic bubble MITC3+ plate
%
x21=TRI_coord(2,1)-TRI_coord(1,1);
y21=TRI_coord(2,2)-TRI_coord(1,2);
x32=TRI_coord(3,1)-TRI_coord(2,1);
y32=TRI_coord(3,2)-TRI_coord(2,2);
x13=TRI_coord(1,1)-TRI_coord(3,1);
y13=TRI_coord(1,2)-TRI_coord(3,2);
J=[x21 y21; -x13 -y13];
%
%  P7 Shape function derivatives
%
P7Dnat=zeros(2,1);
P7Dnat(1,1)=(27*N(1,3))-(54*N(1,2)*N(1,3))-(27*N(1,3)^2);
P7Dnat(2,1)=(27*N(1,2))-(27*N(1,2)^2)-(54*N(1,2)*N(1,3));
j=inv(J);
P7Dcar=zeros(2,1);
P7Dcar(1,1)=j(1,1)*P7Dnat(1,1)+j(1,2)*P7Dnat(2,1);
P7Dcar(2,1)=j(2,1)*P7Dnat(1,1)+j(2,2)*P7Dnat(2,1);
%
%Standard Shape Function
%
Shape1=zeros(3,3*n_Nodes);
for i_sh=1:n_Nodes
    Shape1(1, 3*i_sh-2)=Phi(1,i_sh);
    Shape1(2, 3*i_sh-1)=Phi(1,i_sh);
    Shape1(3, 3*i_sh)=Phi(1,i_sh);
end
clear i_sh
%
%Shape Function of Bubble function
%
Shape2=zeros(3,2);
Shape2(2,1)=27*N(1,1)*N(1,2)*N(1,3);
Shape2(3,2)=27*N(1,1)*N(1,2)*N(1,3);
%
%Bb1 Standard Curvature-Displacement
%
Bbb=zeros(3,3*n_Nodes);
for i_d=1:n_Nodes
    Bbb(1, 3*i_d-1)=DxPhi(1,i_d);
    Bbb(2, 3*i_d)=DyPhi(1,i_d);
    Bbb(3, 3*i_d-1)=DyPhi(1,i_d);
    Bbb(3, 3*i_d)=DxPhi(1,i_d);
end
%
% Bending Curvature for P7 center element 
%
Bbdltb=zeros(3,2);
    Bbdltb(1,1)=P7Dcar(1,1);
    Bbdltb(2,2)=P7Dcar(2,1);
    Bbdltb(3,1)=P7Dcar(2,1);
    Bbdltb(3,2)=P7Dcar(1,1);
%
% From tying point to element node in natural coordinates
%
Ng=[N(1,1)+N(1,2) -sqrt(2)*N(1,3) N(1,3)
    N(1,2) sqrt(2)*N(1,2) N(1,1)+N(1,3)];
% Ss=[1 0 0
%    0 0 1
%    1 0 0
%    1 sqrt(2) 0
%    0 -sqrt(2) 1
%    0 0 1];

%
%The shear strains in the tangential coordinate
%
Ag=zeros(3,3);
Ag(1,1)= L(1);
Ag(2,2)= L(2)/sqrt(2);
Ag(3,3)= -L(3);
Au=0.5*[-2/L(1) C(1) S(1) 2/L(1) C(1) S(1) 0 0 0
    0 0 0 -2/L(2) C(2) S(2) 2/L(2) C(2) S(2)
    2/L(3) C(3) S(3) 0 0 0 -2/L(3) C(3) S(3)];
%
%Bs1 based on T3 / MITC3
%
Bsmitc3=Ng*Ag*Au;
Bsplus=(0.0001-(1/6))*[0 x32*(3*N(1,3)-1) y32*(3*N(1,3)-1) 0 x13*(3*N(1,3)-1) y13*(3*N(1,3)-1) 0 x21*(3*N(1,3)-1) y21*(3*N(1,3)-1);
                      0 x32*(1-3*N(1,2)) y32*(1-3*N(1,2)) 0 x13*(1-3*N(1,2)) y13*(1-3*N(1,2)) 0 x21*(1-3*N(1,2)) y21*(1-3*N(1,2))];
%                  
%Bs based on MITC3
%
Bsb=zeros(2,3*n_Nodes);
Bs=inv(J)*(Bsmitc3+Bsplus);
for i_sh=1:n_Nodes
    if Nodes_I(1,i_sh)== Lnods(1) 
    Bsb(:, 3*i_sh-2)=Bs(:,1);
    Bsb(:, 3*i_sh-1)=Bs(:,2);
    Bsb(:, 3*i_sh)=Bs(:,3);
    elseif Nodes_I(1,i_sh)== Lnods(2)
    Bsb(:, 3*i_sh-2)=Bs(:,4);
    Bsb(:, 3*i_sh-1)=Bs(:,5);
    Bsb(:, 3*i_sh)=Bs(:,6);   
    elseif Nodes_I(1,i_sh)== Lnods(3)
    Bsb(:, 3*i_sh-2)=Bs(:,7);
    Bsb(:, 3*i_sh-1)=Bs(:,8);
    Bsb(:, 3*i_sh)=Bs(:,9);
    end
end
%
%Bs bubble function based on MITC3+
%
Bsdltb=inv(J)*0.5*[x21 y21;
                   -x13 -y13];