function  [Estif, RBody, Au] = Stif_bodyps_MITC3plate( Ielem, Lnods, Coord, IMatno, Props, Cor_type, ...
                           Nsamp, theta, P_order, Nodes, n_Nodes, Ndofn, Body_f_I)
%
%  To generate the stiffness matrix and equivalent nodal body force vector
%  for a kriging plate bending MITC3+ element
%
%  Using the same interpolation functions for displacement and rotations
%
%  Written by Wong Foek Tjong, ID. 100127
%  Asian Institute of Technology, 26 Oct 2005, 30 Jan 2006
%  Modification for MITC3+: 15 April 2021 by Sebastian
%
%  Input
%  Ielem:  Current element number
%  Lnods:  Element node numbers listed per each element
%  Coord:  Coordinate of the node
%  IMatno: Current material property number
%  Props:  Elastic modulus, Poisson's ratio, material thickness
%  Cor_type:  Type of correlation function: 1-Gaussian, 2-Quartic spline
%  Nsamp:  The number of sampling points for the integration
%          of the stiffness matrix and the load vector (1,3,4,6,7,12,13)
%  theta:  The correlation parameter
%  P_order:  The order of the polynomial basis function used in the
%            kriging interpolation
%  Nodes  : Node numbers in an influence domain
%  n_Nodes: Number of nodes in the influence domain
%  Ndofn:  Number of degrees of freedom per nodal point
%  Body_f_I:  Row matirx containing transverse load, moment about x-axis, 
%             moment about y-axis (KN/mm2, KN-mm/mm2, KN-mm/mm2)
%
%  Output
%  Estif:  The element stiffness matrix
%  RBody:  The equivalent nodal force vector due to body force
%
%  Nodal coordinates in the influence domain
%
Coord_DOI=Coord(Nodes,:);  
d_max = Max_Distance( Coord_DOI);
%
%  Sampling points and their weights (in local coordinates)
%
TRI_coord=Coord(Lnods(Ielem,:),:);
[xip, vip] = Tri_integral ...
    (TRI_coord(1,:)', TRI_coord(2,:)', TRI_coord(3,:)', Nsamp);
%
%  Transforming to natural coordinates
%
[Nat_Coord_DOI] = Natural( Coord_DOI, TRI_coord);
%
%  Kriging shape functions and their derivatives
%
[PHI, Nat_DxPHI, Nat_DyPHI] = ...
 Kriging_shapef( Nat_Coord_DOI, theta, d_max, P_order, xip', Cor_type);
clear Nat_Coord_DOI Coord_DOI d_max xip
%
%  Plate constitutive matrices
%
[Db, Ds] = Modps(IMatno, Props);
%
%  Transforming Natural Dx & Dy Phi Using Inverse Jacobian
%
[DxPHI, DyPHI] = NaturalDxDy( Nat_DxPHI, Nat_DyPHI, TRI_coord);
clear Nat_DxPHI Nat_DyPHI
%
%  Sampling points and their weights in Cartesius 
%
TRI_coord=Coord(Lnods(Ielem,:),:);
[xip] = Tri_integral_Cart ...
    (TRI_coord(1,:)', TRI_coord(2,:)', TRI_coord(3,:)', Nsamp);
%
%  Bending stiffness matrix and  nodal body force vector
%
Estif=zeros(3*n_Nodes, 3*n_Nodes);
Kb=zeros(3*n_Nodes, 3*n_Nodes);
RBody=zeros(3*n_Nodes, 1);
kb22=zeros(2, 2);
ks22=zeros(2, 2);
ks12=zeros(3*n_Nodes, 2);
for Isamp=1:Nsamp
   [N, DN, C, S, L, A] = MITC_shape_f (TRI_coord, xip(:,Isamp));
   [Shape1, Shape2, Bbdltb, Bbb, Bsdltb, Bsb] = Shape_fun_MITC3(N, DN, TRI_coord, PHI(Isamp,:), DxPHI(Isamp,:), DyPHI(Isamp,:), ...
                                C, S, A, n_Nodes,L, Nodes, Lnods(Ielem,:));
   kb22 = kb22 + vip(1,Isamp)*Bbdltb'*Db*Bbdltb;
   ks22 = ks22 + vip(1,Isamp)*Bsdltb'*Ds*Bsdltb;
   ks12 = ks12 + vip(1,Isamp)*Bsb'*Ds*Bsdltb; 
end 
%
%  Static Condentation of Bubble function
%
k22=kb22+ks22;
k21=ks12';
Au=-k22\k21;
for Isamp=1:Nsamp
   [N, DN, C, S, L, A] = MITC_shape_f (TRI_coord, xip(:,Isamp));
   [Shape1, Shape2, Bbdltb, Bbb, Bsdltb, Bsb] = Shape_fun_MITC3(N, DN, TRI_coord, PHI(Isamp,:), DxPHI(Isamp,:), DyPHI(Isamp,:), ...
                                C, S, A, n_Nodes,L, Nodes, Lnods(Ielem,:));
    Shape=Shape1+Shape2*Au ; 
    Bb=Bbb+Bbdltb*Au;
    Bs=Bsb+Bsdltb*Au;  
    Estif = Estif + vip(1,Isamp)*Bb'*Db*Bb + vip(1,Isamp)*Bs'*Ds*Bs;
    RBody = RBody + vip(1,Isamp)*Shape'*Body_f_I';
     
end
clear Bs vip DxPHI DyPHI Ds
%
%  Changing the rotation variables to nodal rotations
%
T=sparse(zeros(Ndofn*n_Nodes, Ndofn*n_Nodes));
for i_Es0=1:n_Nodes
   T(3*i_Es0-2, 3*i_Es0-2)= 1;
    T(3*i_Es0-1, 3*i_Es0)= 1;
    T(3*i_Es0, 3*i_Es0-1)= -1;  
end
Estif = T'*Estif*T;